package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcProjectContractMapper;
import com.ruoyi.oa.domain.CmcProjectContract;
import com.ruoyi.oa.service.ICmcProjectContractService;

/**
 * cmc项目合同Service业务层处理
 * 
 * @author cmc
 * @date 2024-04-19
 */
@Service
public class CmcProjectContractServiceImpl implements ICmcProjectContractService 
{
    @Autowired
    private CmcProjectContractMapper cmcProjectContractMapper;

    /**
     * 查询cmc项目合同
     * 
     * @param projectId cmc项目合同主键
     * @return cmc项目合同
     */
    @Override
    public CmcProjectContract selectCmcProjectContractByProjectId(String projectId)
    {
        return cmcProjectContractMapper.selectCmcProjectContractByProjectId(projectId);
    }

    /**
     * 查询cmc项目合同列表
     * 
     * @param cmcProjectContract cmc项目合同
     * @return cmc项目合同
     */
    @Override
    public List<CmcProjectContract> selectCmcProjectContractList(CmcProjectContract cmcProjectContract)
    {
        return cmcProjectContractMapper.selectCmcProjectContractList(cmcProjectContract);
    }

    /**
     * 新增cmc项目合同
     * 
     * @param cmcProjectContract cmc项目合同
     * @return 结果
     */
    @Override
    public int insertCmcProjectContract(CmcProjectContract cmcProjectContract)
    {
        return cmcProjectContractMapper.insertCmcProjectContract(cmcProjectContract);
    }

    /**
     * 修改cmc项目合同
     * 
     * @param cmcProjectContract cmc项目合同
     * @return 结果
     */
    @Override
    public int updateCmcProjectContract(CmcProjectContract cmcProjectContract)
    {
        return cmcProjectContractMapper.updateCmcProjectContract(cmcProjectContract);
    }

    /**
     * 批量删除cmc项目合同
     * 
     * @param contractIds 需要删除的cmc项目合同主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectContractByContractIds(String[] contractIds)
    {
        return cmcProjectContractMapper.deleteCmcProjectContractByContractIds(contractIds);
    }

    /**
     * 批量删除cmc项目合同
     *
     * @param projectIds 需要删除的cmc项目合同主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectContractByProjectIds(String[] projectIds)
    {
        return cmcProjectContractMapper.deleteCmcProjectContractByProjectIds(projectIds);
    }

    /**
     * 删除cmc项目合同信息
     * 
     * @param projectId cmc项目合同主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectContractByProjectId(String projectId)
    {
        return cmcProjectContractMapper.deleteCmcProjectContractByProjectId(projectId);
    }
}
